@@ -35,7 +35,7 @@
 #define DEBUG 1
 #include "gst/vaapi/gstvaapidebug.h"
 
-#if USE_DRM
+#if GST_VAAPI_USE_DRM
 #include <drm_fourcc.h>
 #endif
 
@@ -49,7 +49,7 @@ typedef struct _GstVideoFormatMapMap
 
 #define VA_BYTE_ORDER_NOT_CARE 0
 
-#if USE_DRM
+#if GST_VAAPI_USE_DRM
 #define MAKE_DRM_FORMAT(DRM_FORMAT) G_PASTE(DRM_FORMAT_,DRM_FORMAT)
 #else
 #define MAKE_DRM_FORMAT(DRM_FORMAT) 0
@@ -185,7 +185,7 @@ static const GstVideoFormatMap gst_vaapi_video_default_formats[] = {
 #undef DEF_RGB
 #undef DEF_YUV
 
-static GArray *gst_vaapi_video_formats_map;
+static GArray *gst_vaapi_video_formats_map = NULL;
 
 static inline gboolean
 va_format_is_rgb (const VAImageFormat * va_format)
@@ -254,6 +254,9 @@ get_map_by_gst_format (const GArray * formats, GstVideoFormat format)
   const GstVideoFormatMap *entry;
   guint i;
 
+  if (!formats)
+    return NULL;
+
   for (i = 0; i < formats->len; i++) {
     entry = &g_array_index (formats, GstVideoFormatMap, i);
     if (entry->format == format)
@@ -269,6 +272,9 @@ get_map_by_va_format (const VAImageFormat * va_format)
   const GstVideoFormatMap *entry;
   guint i;
 
+  if (!formats)
+    return NULL;
+
   for (i = 0; i < formats->len; i++) {
     entry = &g_array_index (formats, GstVideoFormatMap, i);
     if (va_format_is_same (&entry->va_format, va_format))
@@ -637,11 +643,14 @@ gst_vaapi_video_format_create_map (VAImageFormat * formats, guint n)
 guint
 gst_vaapi_drm_format_from_va_fourcc (guint32 fourcc)
 {
-#if USE_DRM
+#if GST_VAAPI_USE_DRM
   const GArray *map = gst_vaapi_video_formats_map;
   const GstVideoFormatMap *m;
   guint i;
 
+  if (!map)
+    return GST_VIDEO_FORMAT_UNKNOWN;
+
   /* Note: VA fourcc values are now standardized and shall represent
      a unique format. The associated VAImageFormat is just a hint to
      determine RGBA component ordering */
@@ -670,11 +679,14 @@ gst_vaapi_drm_format_from_va_fourcc (guint32 fourcc)
 GstVideoFormat
 gst_vaapi_video_format_from_drm_format (guint drm_format)
 {
-#if USE_DRM
+#if GST_VAAPI_USE_DRM
   const GArray *map = gst_vaapi_video_formats_map;
   const GstVideoFormatMap *m;
   guint i;
 
+  if (!map)
+    return GST_VIDEO_FORMAT_UNKNOWN;
+
   for (i = 0; i < map->len; i++) {
     m = &g_array_index (map, GstVideoFormatMap, i);
     if (m->drm_format == drm_format)
