@@ -96,21 +96,21 @@ struct _GstVaapiDecoderMap
 };
 
 static const GstVaapiDecoderMap vaapi_decode_map[] = {
-  {GST_VAAPI_CODEC_JPEG, GST_RANK_MARGINAL, "jpeg", "image/jpeg", NULL},
-  {GST_VAAPI_CODEC_MPEG2, GST_RANK_PRIMARY, "mpeg2",
+  {GST_VAAPI_CODEC_JPEG, GST_RANK_NONE, "jpeg", "image/jpeg", NULL},
+  {GST_VAAPI_CODEC_MPEG2, GST_RANK_NONE, "mpeg2",
       "video/mpeg, mpegversion=2, systemstream=(boolean)false", NULL},
-  {GST_VAAPI_CODEC_MPEG4, GST_RANK_PRIMARY, "mpeg4",
+  {GST_VAAPI_CODEC_MPEG4, GST_RANK_NONE, "mpeg4",
       "video/mpeg, mpegversion=4", NULL},
-  {GST_VAAPI_CODEC_H263, GST_RANK_PRIMARY, "h263", "video/x-h263", NULL},
-  {GST_VAAPI_CODEC_H264, GST_RANK_PRIMARY, "h264", "video/x-h264",
+  {GST_VAAPI_CODEC_H263, GST_RANK_NONE, "h263", "video/x-h263", NULL},
+  {GST_VAAPI_CODEC_H264, GST_RANK_NONE, "h264", "video/x-h264",
       gst_vaapi_decode_h264_install_properties},
-  {GST_VAAPI_CODEC_VC1, GST_RANK_PRIMARY, "vc1",
+  {GST_VAAPI_CODEC_VC1, GST_RANK_NONE, "vc1",
       "video/x-wmv, wmvversion=3, format={WMV3,WVC1}", NULL},
-  {GST_VAAPI_CODEC_VP8, GST_RANK_PRIMARY, "vp8", "video/x-vp8", NULL},
-  {GST_VAAPI_CODEC_VP9, GST_RANK_PRIMARY, "vp9", "video/x-vp9", NULL},
-  {GST_VAAPI_CODEC_H265, GST_RANK_PRIMARY, "h265", "video/x-h265", NULL},
-  {GST_VAAPI_CODEC_AV1, GST_RANK_PRIMARY, "av1", "video/x-av1", NULL},
-  {0 /* the rest */ , GST_RANK_PRIMARY + 1, NULL, NULL, NULL},
+  {GST_VAAPI_CODEC_VP8, GST_RANK_NONE, "vp8", "video/x-vp8", NULL},
+  {GST_VAAPI_CODEC_VP9, GST_RANK_NONE, "vp9", "video/x-vp9", NULL},
+  {GST_VAAPI_CODEC_H265, GST_RANK_NONE, "h265", "video/x-h265", NULL},
+  {GST_VAAPI_CODEC_AV1, GST_RANK_NONE, "av1", "video/x-av1", NULL},
+  {0 /* the rest */ , GST_RANK_NONE, NULL, NULL, NULL},
 };
 
 static GstElementClass *parent_class = NULL;
@@ -144,7 +144,7 @@ copy_video_codec_state (const GstVideoCodecState * in_state)
 
   g_return_val_if_fail (in_state != NULL, NULL);
 
-  state = g_slice_new0 (GstVideoCodecState);
+  state = g_new0 (GstVideoCodecState, 1);
   state->ref_count = 1;
   state->info = in_state->info;
   state->caps = gst_caps_copy (in_state->caps);
@@ -192,7 +192,7 @@ static gboolean
 gst_vaapidecode_ensure_allowed_srcpad_caps (GstVaapiDecode * decode)
 {
   GstVaapiDisplay *const display = GST_VAAPI_PLUGIN_BASE_DISPLAY (decode);
-  GstCaps *out_caps, *raw_caps, *va_caps, *dma_caps, *gltexup_caps, *base_caps;
+  GstCaps *out_caps, *raw_caps, *va_caps, *gltexup_caps, *base_caps;
   GArray *formats;
   gint min_width, min_height, max_width, max_height;
   guint mem_types;
@@ -207,7 +207,7 @@ gst_vaapidecode_ensure_allowed_srcpad_caps (GstVaapiDecode * decode)
   if (!decode->decoder)
     return FALSE;
 
-  dma_caps = gltexup_caps = NULL;
+  gltexup_caps = NULL;
 
   formats = gst_vaapi_decoder_get_surface_attributes (decode->decoder,
       &min_width, &min_height, &max_width, &max_height, &mem_types);
@@ -272,8 +272,6 @@ gst_vaapidecode_ensure_allowed_srcpad_caps (GstVaapiDecode * decode)
 #endif
 
   out_caps = va_caps;
-  if (dma_caps)
-    gst_caps_append (out_caps, dma_caps);
   if (gltexup_caps)
     gst_caps_append (out_caps, gltexup_caps);
   gst_caps_append (out_caps, raw_caps);
